########
# Provided
########

variable "tags" {
  type        = map(string)
  description = "Tags for all resources"
}

variable "env" {
  type        = string
  description = "Name of the environment"
}

variable "name_prefix" {
  type        = string
  description = "Naming prefix to make mcs2 happy."
}

########
# Core settings
########

variable "aggregation_name" {
  type        = string
  description = "Name of the aggregation"
}

variable "tools_bucket_name" {
  type        = string
  description = "Name of the S3 bucket where jars, wheels, libs, etc... are located"
}

variable "data_bucket_name" {
  type        = string
  description = "Name of the S3 bucket that holds the data."
}

variable "processing_bucket_name" {
  type        = string
  description = "Name of the S3 bucket that has all of the in-flight and log data."
}

variable "database_name" {
  type        = string
  description = "database name for mdr data"
}

variable "security_configuration_name" {
  type        = string
  description = "Name of the security configuration"
}

variable "wavefront_url" {
  type        = string
  description = "The URL to use for wavefront."
}

########
# Job config
########

variable "job_config_hourly" {
  type        = map(any)
  description = "Job configuration for the hourly job."
}

variable "job_config_daily" {
  type        = map(any)
  description = "Job configuration for the daily job."
}

variable "job_config_24hours" {
  type        = map(any)
  description = "Job configuration for the 24 hours job."
}

variable "job_config_31days" {
  type        = map(any)
  description = "Job configuration for the 31 days job."
}

variable "job_role_arn" {
  type        = string
  description = "ARN of the IAM role to use for the jobs"
}

########
# Job parameters
########

variable "default_mdr_lib_version" {
  type        = string
  description = "The default version of the library to use. This value is used unless one is provided by the config."
}

variable "src_tbl_name" {
  type        = string
  description = "Name of the source table, including the DB component. Used by the hourly job."
}

variable "src_account_id" {
  type        = string
  description = "AWS account ID for the source data, e.g. cdca-dev. Used by the hourly job."
}

variable "athena_workgroup_name" {
  type        = string
  description = "Name of the MDR Athena workgroup. Used by the hourly job."
}

variable "mcs2_env" {
  type        = string
  description = "Name of the mosaic 2 environment, e.g. kcdev01, prd5use1."
}

variable "glue_handler_prefix" {
  type        = string
  description = "prefix that should be override with aggregate name in script s3 location"
  default     = null
}

variable "combo_job_map" {
  type = list(object({
    agg_name         = string
    partition_id_col = string
  }))
  description = "Map with aggregate name and partition_id column"
  default     = []
}
